@@ -844,6 +844,228 @@ make_female_inf_epi_haz <- function(trans,u,h_ix,cube,params,exact = TRUE,tol =
   # end of function
 }
 
+# for use in decoupled SIS sampling
+make_female_inf_epi_haz_decoupled_SIS <- function(trans,u,cube,params,exact = TRUE,tol = 1e-8, h_ix = NULL){
+
+  # which places have input arcs to this transition
+  s <- trans$s
+
+  # weights of those arcs
+  w <- trans$s_w
+
+  # c is dependent on genotype
+  f_gen <- strsplit(x = u[s[1]],split = "_",fixed = TRUE)[[1]][2]
+
+  # rate constants
+  a <- params$a
+  c <- cube$c[f_gen]
+
+
+  # safety check
+  if(check_double(c)){
+    stop("c is missing from cube list; called from 'make_female_inf_epi_haz'")
+  }
+
+  # hazard fn
+  if(exact){
+
+    # EXACT hazards (check enabling degree: for discrete simulation only)
+    return(
+      function(t,M, h){
+        # h is the number of humans in each compartment,
+        # calculate the prevalence of disease here for now
+        # which will be supplied externally from the human model
+        prevalence <- h["H_I"]/sum(h)
+        # safety check
+        FOIv <- a*c*prevalence*M[s[1]]
+        if(all(w <= M[s]) & FOIv > 0){
+          return(FOIv)
+        } else {
+          return(0)
+        }
+      }
+    )
+
+  } else {
+
+    # APPROXIMATE hazards (tolerance around zero; for continuous approximation only)
+    return(
+      function(t,M, h){
+        NH <- sum(h)
+        prevalence <- h["H_I"]/NH
+        # safety check
+        FOIv <- a*c*prevalence*M[s[1]]
+        if(NH <= 1.490116e-08 | FOIv <= 1.490116e-08){
+          haz <- 0
+        } else {
+          haz <- FOIv
+        }
+        # return
+        if(haz < tol){
+          return(0)
+        } else {
+          return(haz)
+        }
+      }
+    )
+
+  }
+  # end of function
+}
+
+# for use in decoupled sampling with Imperial human model 
+make_female_inf_epi_haz_decoupled_Imperial <- function(trans,u,cube,params,exact = TRUE,tol = 1e-8, h_ix = NULL) {
+  # which places have input arcs to this transition
+  s <- trans$s
+
+  f_gen <- strsplit(x = u[s[1]],split = "_",fixed = TRUE)[[1]][2]
+  # weights of those arcs
+  w <- trans$s_w
+
+  # get necessary parameters from Imperial model
+  foi_age <- params$foi_age # FOI for each age group
+  av0 <- params$av0 # daily feeding rate 
+
+  # human infectiousness to mosquitoes by state
+  cT <- cube$cT[f_gen]
+  cU <- cube$cU[f_gen]
+  cD <- cube$cD[f_gen]
+
+  rel_foi <- params$rel_foi 
+  omega <- params$omega 
+
+  fd <- params$fd
+  ID0 <- params$ID0
+  kd <- params$kd
+  d1 <- params$d1
+  gamma1 <- params$gamma1
+
+  # store indices of human state variables for retrieval in hazard evaluation
+  indices <- list()
+  indices[["S"]] <- 1
+  indices[["T"]] <- 2
+  indices[["D"]] <- 3
+  indices[["A"]] <- 4
+  indices[["U"]] <- 5
+  indices[["P"]] <- 6
+  indices[["ICA"]] <- 7
+  indices[["IB"]] <- 8
+  indices[["ID"]] <- 9
+
+  # hazard fn
+  if(exact){
+
+    # EXACT hazards (check enabling degree: for discrete simulation only)
+    return(
+      function(t,M, h, human_trace=NULL){
+        # the transmission probability cA is dependent on the
+        # immunity at the given timepoint, so we calculate that here.
+        # the other c's are time independent
+        # we used lagged values of human states to represent 
+        # latent infection
+        latgam <- 12.5
+
+        if(t < latgam) {
+          # equilibrium values
+          idx <- "1"
+          A <- human_trace[[idx]][, indices[["A"]]]
+          T <- human_trace[[idx]][, indices[["T"]]]
+          U <- human_trace[[idx]][, indices[["U"]]]
+          D <- human_trace[[idx]][, indices[["D"]]]  
+          ID <- human_trace[[idx]][,indices[["ID"]]]
+        } else {
+          t_lag <- floor(t-latgam)  
+          idx <- as.character(t_lag+1)
+
+          A <- human_trace[[idx]][, indices[["A"]]]
+          T <- human_trace[[idx]][, indices[["T"]]]
+          U <- human_trace[[idx]][,indices[["U"]] ]
+          D <- human_trace[[idx]][, indices[["D"]]]  
+          ID <- human_trace[[idx]][, indices[["ID"]]]
+          
+        }
+        A <- h[, indices[["A"]]]
+        T <- h[, indices[["T"]]]
+        U <- h[,indices[["U"]] ]
+        D <- h[, indices[["D"]]]  
+        ID <- h[, indices[["ID"]]]
+
+
+        p_det <- d1 + (1 - d1) / (1 + fd * (ID / ID0) ^ kd)
+        cA <- cU + (cD - cU) * p_det ^ gamma1
+
+        # by age compartment
+        FOIvij <-
+          foi_age * av0 * (cT * T + cD * D + cA * A + cU * U) * rel_foi /
+          omega
+
+        # sum over all age compartments
+        
+        FOIv <- sum(FOIvij)*M[s[1]]
+        
+        if(all(w <= M[s]) & FOIv > 0){
+          return(FOIv)
+        } else {
+          return(0)
+        }
+      }
+    )
+
+  } else {
+
+    # APPROXIMATE hazards (tolerance around zero; for continuous approximation only)
+    return(
+      function(t,M, h, human_trace=NULL){
+        # the transmission probability cA is dependent on the
+        # immunity at the given timepoint, so we calculate that here.
+        # the other c's are time independent
+        # we used lagged values of human states to represent 
+        # latent infection
+        latgam <- 12.5
+        if(t < latgam) {
+          # equilibrium values
+          idx <- "1"
+          A <- human_trace[[idx]][, indices[["A"]]]
+          T <- human_trace[[idx]][, indices[["T"]]]
+          U <- human_trace[[idx]][, indices[["U"]]]
+          D <- human_trace[[idx]][, indices[["D"]]]  
+          ID <- human_trace[[idx]][,indices[["ID"]]]
+        } else {
+          t_lag <- floor(t-latgam)  
+          idx <- as.character(t_lag+1)
+          A <- human_trace[[idx]][, indices[["A"]]]
+          T <- human_trace[[idx]][, indices[["T"]]]
+          U <- human_trace[[idx]][,indices[["U"]] ]
+          D <- human_trace[[idx]][, indices[["D"]]]  
+          ID <- human_trace[[idx]][, indices[["ID"]]]
+        }
+        p_det <- d1 + (1 - d1) / (1 + fd * (ID / ID0) ^ kd)
+        cA <- cU + (cD - cU) * p_det ^ gamma1
+
+        # by age compartment
+        FOIvij <-
+          foi_age * av0 * (cT * T + cD * D + cA * A + cU * U) * rel_foi /
+          omega
+
+        # sum over all age compartments
+        
+        FOIv <- sum(FOIvij)*M[s[1]]
+        if(FOIv <= 1.490116e-08){
+          haz <- 0
+        } else {
+          haz <- FOIv
+        }
+        # return
+        if(haz < tol){
+          return(0)
+        } else {
+          return(haz)
+        }
+      }
+    )
+
+  }
+}
 
 ################################################################################
 # FEMALE MOSQUITO INCUBATION (EIP) HAZARD
